@@ -70,6 +70,12 @@ sub _validate_code {
     return $val;
 }
 
+sub _validate_regex {
+    my ($opt, $val) = @_;
+    is_rx($val) or croak "$HOOK: $opt\'s value must be a qr/REGEX/.\n";
+    return $val;
+}
+
 my %opt_checks = (
     projects          => \&_validate_projects,
     require           => \&_validate_bool,
@@ -80,6 +86,7 @@ my %opt_checks = (
     check_all         => \&_validate_code,
     check_all_svnlook => \&_validate_code,
     post_action       => \&_validate_code,
+    exclude           => \&_validate_regex,
 );
 
 sub CHECK_JIRA {
@@ -168,6 +175,8 @@ sub _check_if_needed {
 
 	for my $file (@files) {
 	    if ($file =~ $regex) {
+		# skip exclusions
+		next if exists $opts->{exclude} && $file =~ $opts->{exclude};
 
 		# Grok the JIRA issue keys from the commit log
 		my ($match) = ($svnlook->log_msg() =~ $MatchLog);
@@ -229,7 +238,7 @@ SVN::Hooks::CheckJira - Integrate Subversion with the JIRA ticketing system.
 
 =head1 VERSION
 
-version 1.17
+version 1.18
 
 =head1 DESCRIPTION
 
@@ -368,6 +377,14 @@ information about the commit proper.  The following arguments are the
 JIRA keys mentioned in the commit log message. The value returned by
 the routine, if any, is ignored.
 
+=item exclude => REGEXP
+
+Normally you specify a CHECK_JIRA with a regex matching a root
+directory in the repository hierarchy. Sometimes you need to specify
+some subparts of that root directory that shouldn't be treated by this
+CHECK_JIRA directive. You can use this option to specify these
+exclusions by means of another regex.
+
 =back
 
 You can set defaults for these options using a CHECK_JIRA directive
@@ -426,6 +443,14 @@ add a comment to each refered issue like this:
         post_action => add_comment("Subversion Commit r{rev} by {author} on {date}\n{log_msg}")
     });
 
+You can use a generic CHECK_JIRA excluding specific directories from
+it using the "exclude" option like this:
+
+    CHECK_JIRA(qr:^(trunk|branches/[^/]): => {
+        exclude => qr:/documentation/:,
+        # other options...
+    });
+
 =for Pod::Coverage post_commit pre_commit
 
 =head1 AUTHOR
